@@ -160,7 +160,21 @@ var NAVTREE =
     [ "Doxygen usage", "doxygen_usage.html", [
       [ "Fine-tuning the output", "doxygen_usage.html#doxygen_finetune", null ]
     ] ],
-    [ "Doxywizard usage", "doxywizard_usage.html", null ],
+    [ "Doxywizard usage", "doxywizard_usage.html", [
+      [ "Wizard tab", "doxywizard_usage.html#dw_wizard", [
+        [ "Project settings", "doxywizard_usage.html#dw_wizard_project", null ],
+        [ "Mode of operating", "doxywizard_usage.html#dw_wizard_mode", null ],
+        [ "Output to produce", "doxywizard_usage.html#dw_wizard_output", null ],
+        [ "Diagrams to generate", "doxywizard_usage.html#dw_wizard_diagrams", null ]
+      ] ],
+      [ "Expert tab", "doxywizard_usage.html#dw_expert", null ],
+      [ "Run tab", "doxywizard_usage.html#dw_run", null ],
+      [ "Menu options", "doxywizard_usage.html#dw_menu", [
+        [ "File menu", "doxywizard_usage.html#dw_menu_file", null ],
+        [ "Settings menu", "doxywizard_usage.html#dw_menu_settings", null ],
+        [ "Help menu", "doxywizard_usage.html#dw_menu_help", null ]
+      ] ]
+    ] ],
     [ "Configuration", "config.html", [
       [ "Format", "config.html#config_format", null ],
       [ "Project related configuration options", "config.html#config_project", null ],
@@ -397,6 +411,10 @@ var NAVTREE =
     [ "Perl Module Tree Nodes", "perlmod_tree.html", null ],
     [ "Doxygen's Internals", "arch.html", null ],
     [ "Changelog", "changelog.html", [
+      [ "1.9 Series", "changelog.html#log_1_9", [
+        [ "Release 1.9.1", "changelog.html#log_1_9_1", null ],
+        [ "Release 1.9.0", "changelog.html#log_1_9_0", null ]
+      ] ],
       [ "1.8 Series", "changelog.html#log_1_8", [
         [ "Release 1.8.20", "changelog.html#log_1_8_20", null ],
         [ "Release 1.8.19", "changelog.html#log_1_8_19", null ],
@@ -438,7 +456,7 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "arch.html",
-"config.html#config_messages"
+"config.html#config_input"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
