@@ -9,37 +9,42 @@ var NAVTREEINDEX0 =
 "autolink.html#linkurl":[10,0],
 "autolink.html#resolving":[10,5],
 "changelog.html":[30],
-"changelog.html#log_1_1":[30,7],
-"changelog.html#log_1_2":[30,6],
-"changelog.html#log_1_3":[30,5],
-"changelog.html#log_1_4":[30,4],
-"changelog.html#log_1_5":[30,3],
-"changelog.html#log_1_6":[30,2],
-"changelog.html#log_1_7":[30,1],
-"changelog.html#log_1_8":[30,0],
-"changelog.html#log_1_8_0":[30,0,22],
-"changelog.html#log_1_8_1":[30,0,21],
-"changelog.html#log_1_8_10":[30,0,8],
-"changelog.html#log_1_8_11":[30,0,7],
-"changelog.html#log_1_8_12":[30,0,6],
-"changelog.html#log_1_8_13":[30,0,5],
-"changelog.html#log_1_8_14":[30,0,4],
-"changelog.html#log_1_8_15":[30,0,3],
-"changelog.html#log_1_8_16":[30,0,2],
-"changelog.html#log_1_8_17":[30,0,1],
-"changelog.html#log_1_8_18":[30,0,0],
-"changelog.html#log_1_8_1_1":[30,0,20],
-"changelog.html#log_1_8_1_2":[30,0,19],
-"changelog.html#log_1_8_2":[30,0,18],
-"changelog.html#log_1_8_3":[30,0,17],
-"changelog.html#log_1_8_3_1":[30,0,16],
-"changelog.html#log_1_8_4":[30,0,15],
-"changelog.html#log_1_8_5":[30,0,14],
-"changelog.html#log_1_8_6":[30,0,13],
-"changelog.html#log_1_8_7":[30,0,12],
-"changelog.html#log_1_8_8":[30,0,11],
-"changelog.html#log_1_8_9":[30,0,10],
-"changelog.html#log_1_8_9_1":[30,0,9],
+"changelog.html#log_1_1":[30,8],
+"changelog.html#log_1_2":[30,7],
+"changelog.html#log_1_3":[30,6],
+"changelog.html#log_1_4":[30,5],
+"changelog.html#log_1_5":[30,4],
+"changelog.html#log_1_6":[30,3],
+"changelog.html#log_1_7":[30,2],
+"changelog.html#log_1_8":[30,1],
+"changelog.html#log_1_8_0":[30,1,24],
+"changelog.html#log_1_8_1":[30,1,23],
+"changelog.html#log_1_8_10":[30,1,10],
+"changelog.html#log_1_8_11":[30,1,9],
+"changelog.html#log_1_8_12":[30,1,8],
+"changelog.html#log_1_8_13":[30,1,7],
+"changelog.html#log_1_8_14":[30,1,6],
+"changelog.html#log_1_8_15":[30,1,5],
+"changelog.html#log_1_8_16":[30,1,4],
+"changelog.html#log_1_8_17":[30,1,3],
+"changelog.html#log_1_8_18":[30,1,2],
+"changelog.html#log_1_8_19":[30,1,1],
+"changelog.html#log_1_8_1_1":[30,1,22],
+"changelog.html#log_1_8_1_2":[30,1,21],
+"changelog.html#log_1_8_2":[30,1,20],
+"changelog.html#log_1_8_20":[30,1,0],
+"changelog.html#log_1_8_3":[30,1,19],
+"changelog.html#log_1_8_3_1":[30,1,18],
+"changelog.html#log_1_8_4":[30,1,17],
+"changelog.html#log_1_8_5":[30,1,16],
+"changelog.html#log_1_8_6":[30,1,15],
+"changelog.html#log_1_8_7":[30,1,14],
+"changelog.html#log_1_8_8":[30,1,13],
+"changelog.html#log_1_8_9":[30,1,12],
+"changelog.html#log_1_8_9_1":[30,1,11],
+"changelog.html#log_1_9":[30,0],
+"changelog.html#log_1_9_0":[30,0,1],
+"changelog.html#log_1_9_1":[30,0,0],
 "commands.html":[22],
 "commands.html#cmd_intro":[22,0],
 "commands.html#cmda":[22,134],
@@ -239,15 +244,10 @@ var NAVTREEINDEX0 =
 "config.html#config_autogen":[21,13],
 "config.html#config_build":[21,2],
 "config.html#config_docbook":[21,12],
-"config.html#config_dot":[21,17],
-"config.html#config_examples":[21,18],
-"config.html#config_external":[21,16],
+"config.html#config_dot":[21,18],
+"config.html#config_examples":[21,19],
+"config.html#config_external":[21,17],
 "config.html#config_format":[21,0],
 "config.html#config_html":[21,7],
-"config.html#config_index":[21,6],
-"config.html#config_input":[21,4],
-"config.html#config_latex":[21,8],
-"config.html#config_man":[21,10],
-"config.html#config_messages":[21,3],
-"config.html#config_perlmod":[21,14]
+"config.html#config_index":[21,6]
 };
