@@ -1,5 +1,8 @@
 var NAVTREEINDEX1 =
 {
+"config.html#config_input":[21,4],
+"config.html#config_latex":[21,8],
+"config.html#config_man":[21,10],
 "config.html#config_messages":[21,3],
 "config.html#config_perlmod":[21,15],
 "config.html#config_preprocessor":[21,16],
@@ -34,6 +37,17 @@ var NAVTREEINDEX1 =
 "doxygen_usage.html":[19],
 "doxygen_usage.html#doxygen_finetune":[19,0],
 "doxywizard_usage.html":[20],
+"doxywizard_usage.html#dw_expert":[20,1],
+"doxywizard_usage.html#dw_menu":[20,3],
+"doxywizard_usage.html#dw_menu_file":[20,3,0],
+"doxywizard_usage.html#dw_menu_help":[20,3,2],
+"doxywizard_usage.html#dw_menu_settings":[20,3,1],
+"doxywizard_usage.html#dw_run":[20,2],
+"doxywizard_usage.html#dw_wizard":[20,0],
+"doxywizard_usage.html#dw_wizard_diagrams":[20,0,3],
+"doxywizard_usage.html#dw_wizard_mode":[20,0,1],
+"doxywizard_usage.html#dw_wizard_output":[20,0,2],
+"doxywizard_usage.html#dw_wizard_project":[20,0,0],
 "emojisup.html":[25],
 "emojisup.html#emojiimage":[25,1],
 "emojisup.html#emojirep":[25,0],
